@@ -3,6 +3,8 @@ import requests
 import logging
 import pandas as pd
 
+from typing import Optional
+
 
 class Vavaprice_Helper():
     def __init__(self, url, token):
@@ -21,7 +23,7 @@ class Vavaprice_Helper():
         }
 
 
-    def get_quotation(self, car, debug=False):
+    def get_quotation(self, car, debug=None, client: Optional[str] = None):
         """
         Gets an a quotation for a vehicle
 
@@ -36,7 +38,8 @@ class Vavaprice_Helper():
                 - trim: string
                 - km: integer
                 - glassroof: boolean
-            debug (boolean|str): if not False|None adds debug key in quotation request to retrieve prices of disabled make/model 
+            debug (boolean|str): if not False|None adds debug key in quotation request to retrieve prices of disabled make/model
+            client (str): string to indicate which app is calling the Pricing Engine
         Returns:
             quotation (pd.Series): Columns:
                 - adjmargin: Margin due to price adjusting (fix_price)
@@ -47,7 +50,11 @@ class Vavaprice_Helper():
                 - miscmargin: Margin due to other factors (glassroof, temporary strategy, ..)
                 - discounttype: "Camunda" or "CamundaError"
         """
-        
+
+        if client is None:
+            client = debug if isinstance(debug, str) else 'unknown' # for compatibility with previous versions
+            logging.warning(f"Should have specified a value for parameter 'client', setting '{client}' for now.")
+
         input_data = {
             "makename": car['make'],
             "modelname": car['model'],
@@ -57,7 +64,8 @@ class Vavaprice_Helper():
             "trim": car['trim'],
             "year": car['year'],
             "mileage": car['km'],
-            "glassroof": car.get('glassroof', 0)
+            "glassroof": car.get('glassroof', 0),
+            "client": client
         }
 
         if debug:
@@ -68,6 +76,7 @@ class Vavaprice_Helper():
         try:
 
             response = requests.request("POST", self._url, headers=self._headers, data=payload)
+            response.raise_for_status()
             return pd.Series(json.loads(response.text))
 
         except Exception as e:
